@@ -2,7 +2,7 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 
     SPDX-FileCopyrightText: 2003 Alexander Blum <blum@kewbee.de>
-    SPDX-FileCopyrightText: 2004-2020 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
+    SPDX-FileCopyrightText: 2004-2022 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
 */
 
 #include "aswriter.h"
@@ -13,6 +13,7 @@
 #include "debug_utils.h"
 #include "operation.h"
 #include "umldoc.h"
+#include "uml.h"  // Only needed for logWarn
 
 #include <QRegExp>
 #include <QTextStream>
@@ -474,7 +475,7 @@ ASWriter::~ASWriter()
 void ASWriter::writeClass(UMLClassifier *c)
 {
     if (!c) {
-        uDebug()<<"Cannot write class of NULL concept!";
+        logWarn0("ASWriter::writeClass: Cannot write class of NULL concept!");
         return;
     }
 
